@@ -9,7 +9,7 @@ def process_omics(
     min_cell: int = 3,
     min_counts: int = 3,
     n_top_genes: int = 2000,
-    subset_hvg: bool = False,
+    subset_hvg: bool = True,
 ) -> None:
     r"""
     Process the omics data.
